import logging

from django.forms import (
    BooleanField,
    CharField,
    Form,
    HiddenInput,
    ModelForm,
)
from django.utils.translation import gettext_lazy as _

from ..models import (
    CategorisationRule,
    Event,
)

logger = logging.getLogger(__name__)


class CategorisationRuleImportForm(ModelForm):
    required_css_class = "required"

    class Meta:
        model = CategorisationRule
        fields = "__all__"


class CategorisationForm(Form):
    required_css_class = "required"

    def __init__(self, *args, **kwargs):
        if "events" in kwargs:
            events = kwargs.pop("events", None)
        else:
            events = []
            for f in args[0]:
                if "_" not in f:
                    if f + "_cat" in args[0]:
                        events.append(
                            (Event.objects.get(pk=int(f)), args[0][f + "_cat"])
                        )
        super().__init__(*args, **kwargs)

        for e, c in events:
            self.fields[str(e.pk)] = BooleanField(
                initial=False,
                label=_("Apply category {} to the event {}").format(c, e.title),
                required=False,
            )
            self.fields[str(e.pk) + "_cat"] = CharField(initial=c, widget=HiddenInput())

    def get_validated(self):
        return [
            (e, self.cleaned_data.get(e + "_cat"))
            for e in self.fields
            if "_" not in e and self.cleaned_data.get(e)
        ]
