from django.forms import (
    CharField,
    Form,
    ModelChoiceField,
    ModelForm,
    MultipleChoiceField,
    Textarea,
)
from django.utils.translation import gettext_lazy as _

from ..models import (
    Category,
    RecurrentImport,
    Tag,
)


class BatchImportationForm(Form):
    required_css_class = "required"

    data = CharField(
        label=_("Data"),
        widget=Textarea(attrs={"rows": "10"}),
        help_text=_("Supported formats: json, html."),
        required=True,
    )

    category = ModelChoiceField(
        label=_("Category"),
        queryset=Category.objects.all().order_by("name"),
        help_text=_("Used only if data is html."),
        initial=None,
        required=False,
    )
    tags = MultipleChoiceField(
        label=_("Tags"),
        initial=None,
        choices=[],
        help_text=_("Used only if data is html."),
        required=False,
    )

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["tags"].choices = Tag.get_tag_groups(all=True)


class RecurrentImportForm(ModelForm):
    required_css_class = "required"

    defaultTags = MultipleChoiceField(
        label=_("Tags"), initial=None, choices=[], required=False
    )

    class Meta:
        model = RecurrentImport
        fields = "__all__"

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["defaultTags"].choices = Tag.get_tag_groups(all=True)
