from django.forms import (
    HiddenInput,
    ModelForm,
)
from django.utils.translation import gettext_lazy as _

from ..models import (
    Message,
)


class MessageForm(ModelForm):
    class Meta:
        model = Message
        fields = ["subject", "name", "email", "message", "related_event"]
        widgets = {"related_event": HiddenInput(), "user": HiddenInput()}

    def __init__(self, *args, **kwargs):
        self.event = kwargs.pop("event", False)
        self.internal = kwargs.pop("internal", False)
        super().__init__(*args, **kwargs)
        self.fields["related_event"].required = False
        if self.internal:
            self.fields.pop("name")
            self.fields.pop("email")


class MessageEventForm(ModelForm):
    class Meta:
        model = Message
        fields = ["message"]

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["message"].label = _("Add a comment")
