from django.forms import (
    BooleanField,
    CharField,
    Form,
    HiddenInput,
    ModelForm,
)
from django.utils.translation import gettext_lazy as _

from ..models import (
    Tag,
)


class TagForm(ModelForm):
    required_css_class = "required"

    class Meta:
        model = Tag
        fields = [
            "name",
            "description",
            "message",
            "in_included_suggestions",
            "in_excluded_suggestions",
            "principal",
        ]

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        if "name" in kwargs["initial"]:
            self.fields["name"].widget = HiddenInput()


class TagRenameForm(Form):
    required_css_class = "required"

    name = CharField(label=_("Name of new tag"), required=True)

    force = BooleanField(
        label=_(
            "Force renaming despite the existence of events already using the chosen tag."
        ),
    )

    def __init__(self, *args, **kwargs):
        force = kwargs.pop("force", False)
        name = kwargs.pop("name", None)
        super().__init__(*args, **kwargs)
        if not (force or (not len(args) == 0 and "force" in args[0])):
            del self.fields["force"]
        if name is not None and self.fields["name"].initial is None:
            self.fields["name"].initial = name

    def is_force(self):
        return "force" in self.fields and self.cleaned_data["force"] is True
